==> healthrian_visualization_support-1.0.36.tar.gz: lib/src/widgets/cardio_click/battery_level_cardioclick.dart <==
// ignore_for_file: public_member_api_docs

import 'dart:math';

import 'package:copy_with_extension/copy_with_extension.dart';
import 'package:flutter/material.dart';
import 'package:flutter_mobx/flutter_mobx.dart';
import 'package:healthrian_ble_support/healthrian_ble_support.dart';

part 'battery_level_cardioclick.g.dart';

@CopyWith()
class BatteryLevelCardioClick extends StatelessWidget {
  const BatteryLevelCardioClick({
    super.key,
    this.height = 50,
    this.onLoadingWidget,
    this.wrapperWidget,
  });

  final double height;
  final Widget? onLoadingWidget;

  final Widget Function(int)? wrapperWidget;

  @override
  Widget build(BuildContext context) {
    final f = wrapperWidget ??
        (int value) {
          const levels = [
            Icon(
              Icons.battery_full,
              color: Colors.green,
            ),
            Icon(
              Icons.battery_6_bar,
              color: Colors.green,
            ),
            Icon(
              Icons.battery_5_bar,
              color: Colors.green,
            ),
            Icon(
              Icons.battery_4_bar,
              color: Colors.amber,
            ),
            Icon(
              Icons.battery_3_bar,
              color: Colors.amber,
            ),
            Icon(
              Icons.battery_2_bar,
              color: Colors.amber,
            ),
            Icon(
              Icons.battery_1_bar,
              color: Colors.redAccent,
            ),
            Icon(
              Icons.battery_0_bar,
              color: Colors.redAccent,
            ),
          ];

          final index = 7 - ((value - 1) ~/ 12.5);
          return Row(
            children: [
              Transform.rotate(
                angle: pi / 2,
                child: levels[index],
              ),
              Text('$value%'),
            ],
          );
        };

    return Observer(
      key: UniqueKey(),
      builder: (context) {
        return StreamBuilder(
          stream: BLEManager().manageCardioClick.streams.batteryLevelStream,
          builder: (context, snapshot) {
            if (!snapshot.hasData) return onLoadingWidget ?? const SizedBox();
            return f(snapshot.data!);
          },
        );
      },
    );
  }
}

==> healthrian_visualization_support-1.0.49.tar.gz: lib/src/widgets/cardio_click/battery_level_cardioclick.dart <==
// ignore_for_file: public_member_api_docs

import 'dart:math';

import 'package:copy_with_extension/copy_with_extension.dart';
import 'package:flutter/material.dart';
import 'package:flutter_mobx/flutter_mobx.dart';
import 'package:healthrian_ble_support/healthrian_ble_support.dart';

part 'battery_level_cardioclick.g.dart';

@CopyWith()
class BatteryLevelCardioClick extends StatelessWidget {
  const BatteryLevelCardioClick({
    super.key,
    this.height = 50,
    this.onLoadingWidget,
    this.wrapperWidget,
  });

  final double height;
  final Widget? onLoadingWidget;

  final Widget Function(int)? wrapperWidget;

  @override
  Widget build(BuildContext context) {
    final f = wrapperWidget ??
        (int value) {
          const levels = [
            Icon(
              Icons.battery_full,
              color: Colors.green,
            ),
            Icon(
              Icons.battery_6_bar,
              color: Colors.green,
            ),
            Icon(
              Icons.battery_5_bar,
              color: Colors.green,
            ),
            Icon(
              Icons.battery_4_bar,
              color: Colors.amber,
            ),
            Icon(
              Icons.battery_3_bar,
              color: Colors.amber,
            ),
            Icon(
              Icons.battery_2_bar,
              color: Colors.amber,
            ),
            Icon(
              Icons.battery_1_bar,
              color: Colors.redAccent,
            ),
            Icon(
              Icons.battery_0_bar,
              color: Colors.redAccent,
            ),
          ];

          final index = 7 - ((value - 1) ~/ 12.5);
          return Row(
            children: [
              Transform.rotate(
                angle: pi / 2,
                child: levels[index],
              ),
              Text('$value%'),
            ],
          );
        };

    return Observer(
      key: UniqueKey(),
      builder: (context) {
        return StreamBuilder<int>(
          stream: BLEManager().manageCardioClick.streams.batteryLevelStream,
          builder: (context, snapshot) {
            if (!snapshot.hasData) return onLoadingWidget ?? const SizedBox();
            return f(snapshot.data!);
          },
        );
      },
    );
  }
}
